@@ -38,9 +38,9 @@ except ImportError:
         pass
 
 
-def verify_help_text(cmd2_app: cmd2.Cmd,
-                     help_output: Union[str, List[str]],
-                     verbose_strings: Optional[List[str]] = None) -> None:
+def verify_help_text(
+    cmd2_app: cmd2.Cmd, help_output: Union[str, List[str]], verbose_strings: Optional[List[str]] = None
+) -> None:
     """This function verifies that all expected commands are present in the help text.
 
     :param cmd2_app: instance of cmd2.Cmd
@@ -130,7 +130,7 @@ timing: False             # Report execution times
 
 
 def normalize(block):
-    """ Normalize a block of text to perform comparison.
+    """Normalize a block of text to perform comparison.
 
     Strip newlines from the very beginning and very end  Then split into separate lines and strip trailing whitespace
     from each line.
@@ -141,7 +141,7 @@ def normalize(block):
 
 
 def run_cmd(app, cmd):
-    """ Clear out and err StdSim buffers, run the command, and return out and err """
+    """Clear out and err StdSim buffers, run the command, and return out and err"""
     saved_sysout = sys.stdout
     sys.stdout = app.stdout
 
@@ -167,16 +167,11 @@ def run_cmd(app, cmd):
 
 @fixture
 def base_app():
-    return cmd2.Cmd()
+    return cmd2.Cmd(include_py=True, include_ipy=True)
 
 
 # These are odd file names for testing quoting of them
-odd_file_names = [
-    'nothingweird',
-    'has   spaces',
-    '"is_double_quoted"',
-    "'is_single_quoted'"
-]
+odd_file_names = ['nothingweird', 'has   spaces', '"is_double_quoted"', "'is_single_quoted'"]
 
 
 def complete_tester(text: str, line: str, begidx: int, endidx: int, app) -> Optional[str]:
@@ -195,6 +190,7 @@ def complete_tester(text: str, line: str, begidx: int, endidx: int, app) -> Opti
              Matches are stored in app.completion_matches
              These matches also have been sorted by complete()
     """
+
     def get_line():
         return line
 
