@@ -13,7 +13,7 @@ import pytest
 
 import cmd2
 from cmd2 import (
-    utils,
+    Settable,
 )
 from cmd2.exceptions import (
     CommandSetRegistrationError,
@@ -22,6 +22,8 @@ from cmd2.exceptions import (
 from .conftest import (
     WithCommandSets,
     complete_tester,
+    normalize,
+    run_cmd,
 )
 
 
@@ -61,9 +63,8 @@ class CommandSetA(CommandSetBase):
     def do_cranberry(self, ns: argparse.Namespace, unknown: List[str]):
         self._cmd.poutput('Cranberry {}!!'.format(ns.arg1))
         if unknown and len(unknown):
-            self._cmd.poutput('Unknown: ' + ', '.join(['{}']*len(unknown)).format(*unknown))
-        self._cmd.last_result = {'arg1': ns.arg1,
-                           'unknown': unknown}
+            self._cmd.poutput('Unknown: ' + ', '.join(['{}'] * len(unknown)).format(*unknown))
+        self._cmd.last_result = {'arg1': ns.arg1, 'unknown': unknown}
 
     def help_cranberry(self):
         self._cmd.stdout.write('This command does diddly squat...\n')
@@ -73,11 +74,11 @@ class CommandSetA(CommandSetBase):
     def do_durian(self, args: List[str]):
         """Durian Command"""
         self._cmd.poutput('{} Arguments: '.format(len(args)))
-        self._cmd.poutput(', '.join(['{}']*len(args)).format(*args))
+        self._cmd.poutput(', '.join(['{}'] * len(args)).format(*args))
         self._cmd.last_result = {'args': args}
 
     def complete_durian(self, text: str, line: str, begidx: int, endidx: int) -> List[str]:
-        return utils.basic_complete(text, line, begidx, endidx, ['stinks', 'smells', 'disgusting'])
+        return self._cmd.basic_complete(text, line, begidx, endidx, ['stinks', 'smells', 'disgusting'])
 
     elderberry_parser = cmd2.Cmd2ArgumentParser()
     elderberry_parser.add_argument('arg1')
@@ -156,7 +157,7 @@ def test_custom_construct_commandsets():
     cmds_cats, cmds_doc, cmds_undoc, help_topics = app._build_command_info()
     assert 'Command Set B' in cmds_cats
 
-    # Verifies that the same CommandSet can not be loaded twice
+    # Verifies that the same CommandSet cannot be loaded twice
     command_set_2 = CommandSetB('bar')
     with pytest.raises(CommandSetRegistrationError):
         assert app.register_command_set(command_set_2)
@@ -256,28 +257,24 @@ def test_commandset_decorators(command_sets_app):
     assert 'extra1' in result.data['unknown']
     assert 'extra2' in result.data['unknown']
     assert result.data['arg1'] == 'juice'
-    assert result.stderr is None
+    assert not result.stderr
 
     result = command_sets_app.app_cmd('durian juice extra1 extra2')
     assert len(result.data['args']) == 3
     assert 'juice' in result.data['args']
     assert 'extra1' in result.data['args']
     assert 'extra2' in result.data['args']
-    assert result.stderr is None
+    assert not result.stderr
 
     result = command_sets_app.app_cmd('durian')
     assert len(result.data['args']) == 0
-    assert result.stderr is None
+    assert not result.stderr
 
     result = command_sets_app.app_cmd('elderberry')
-    assert result.stderr is not None
-    assert len(result.stderr) > 0
     assert 'arguments are required' in result.stderr
     assert result.data is None
 
     result = command_sets_app.app_cmd('elderberry a b')
-    assert result.stderr is not None
-    assert len(result.stderr) > 0
     assert 'unrecognized arguments' in result.stderr
     assert result.data is None
 
@@ -449,7 +446,7 @@ class LoadableVegetables(cmd2.CommandSet):
         return ['quartered', 'diced']
 
     bokchoy_parser = cmd2.Cmd2ArgumentParser()
-    bokchoy_parser.add_argument('style', completer_method=complete_style_arg)
+    bokchoy_parser.add_argument('style', completer=complete_style_arg)
 
     @cmd2.as_subcommand_to('cut', 'bokchoy', bokchoy_parser)
     def cut_bokchoy(self, ns: argparse.Namespace):
@@ -577,6 +574,7 @@ def test_subcommands(command_sets_manual):
     command_sets_manual.unregister_command_set(veg_cmds)
     command_sets_manual.unregister_command_set(base_cmds)
 
+
 def test_nested_subcommands(command_sets_manual):
     base_cmds = LoadableBase(1)
     pasta_cmds = LoadablePastaStir(1)
@@ -624,6 +622,7 @@ def test_nested_subcommands(command_sets_manual):
 
 class AppWithSubCommands(cmd2.Cmd):
     """Class for testing usage of `as_subcommand_to` decorator directly in a Cmd2 subclass."""
+
     def __init__(self, *args, **kwargs):
         super(AppWithSubCommands, self).__init__(*args, **kwargs)
 
@@ -654,7 +653,7 @@ class AppWithSubCommands(cmd2.Cmd):
         return ['quartered', 'diced']
 
     bokchoy_parser = cmd2.Cmd2ArgumentParser()
-    bokchoy_parser.add_argument('style', completer_method=complete_style_arg)
+    bokchoy_parser.add_argument('style', completer=complete_style_arg)
 
     @cmd2.as_subcommand_to('cut', 'bokchoy', bokchoy_parser)
     def cut_bokchoy(self, _: argparse.Namespace):
@@ -705,12 +704,12 @@ class WithCompleterCommandSet(cmd2.CommandSet):
 
     def complete_states(self, text: str, line: str, begidx: int, endidx: int) -> List[str]:
         assert self is complete_states_expected_self
-        return utils.basic_complete(text, line, begidx, endidx, self.states)
+        return self._cmd.basic_complete(text, line, begidx, endidx, self.states)
 
 
 class SubclassCommandSetCase1(WithCompleterCommandSet):
     parser = cmd2.Cmd2ArgumentParser()
-    parser.add_argument('state', type=str, completer_method=WithCompleterCommandSet.complete_states)
+    parser.add_argument('state', type=str, completer=WithCompleterCommandSet.complete_states)
 
     @cmd2.with_argparser(parser)
     def do_case1(self, ns: argparse.Namespace):
@@ -719,7 +718,7 @@ class SubclassCommandSetCase1(WithCompleterCommandSet):
 
 class SubclassCommandSetErrorCase2(WithCompleterCommandSet):
     parser = cmd2.Cmd2ArgumentParser()
-    parser.add_argument('state', type=str, completer_method=WithCompleterCommandSet.complete_states)
+    parser.add_argument('state', type=str, completer=WithCompleterCommandSet.complete_states)
 
     @cmd2.with_argparser(parser)
     def do_error2(self, ns: argparse.Namespace):
@@ -732,7 +731,7 @@ class SubclassCommandSetCase2(cmd2.CommandSet):
         super(SubclassCommandSetCase2, self).__init__()
 
     parser = cmd2.Cmd2ArgumentParser()
-    parser.add_argument('state', type=str, completer_method=WithCompleterCommandSet.complete_states)
+    parser.add_argument('state', type=str, completer=WithCompleterCommandSet.complete_states)
 
     @cmd2.with_argparser(parser)
     def do_case2(self, ns: argparse.Namespace):
@@ -742,7 +741,7 @@ class SubclassCommandSetCase2(cmd2.CommandSet):
 def test_cross_commandset_completer(command_sets_manual):
     global complete_states_expected_self
     # This tests the different ways to locate the matching CommandSet when completing an argparse argument.
-    # Exercises the `_complete_for_arg` function of `ArgparseCompleter` in `argparse_completer.py`
+    # Exercises the `_complete_arg` function of `ArgparseCompleter` in `argparse_completer.py`
 
     ####################################################################################################################
     # This exercises Case 1
@@ -862,8 +861,8 @@ class CommandSetWithPathComplete(cmd2.CommandSet):
         """dummy variable prevents this from being autoloaded in other tests"""
         super(CommandSetWithPathComplete, self).__init__()
 
-    parser = argparse.ArgumentParser()
-    parser.add_argument('path', nargs='+', help='paths', completer_method=cmd2.Cmd.path_complete)
+    parser = cmd2.Cmd2ArgumentParser()
+    parser.add_argument('path', nargs='+', help='paths', completer=cmd2.Cmd.path_complete)
 
     @cmd2.with_argparser(parser)
     def do_path(self, app: cmd2.Cmd, args):
@@ -909,3 +908,175 @@ def test_bad_subcommand():
 
     with pytest.raises(CommandSetRegistrationError):
         app = BadSubcommandApp()
+
+
+def test_commandset_settables():
+    # Define an arbitrary class with some attribute
+    class Arbitrary:
+        def __init__(self):
+            self.some_value = 5
+
+    # Declare a CommandSet with a settable of some arbitrary property
+    class WithSettablesA(CommandSetBase):
+        def __init__(self):
+            super(WithSettablesA, self).__init__()
+
+            self._arbitrary = Arbitrary()
+            self._settable_prefix = 'addon'
+            self.my_int = 11
+
+            self.add_settable(
+                Settable(
+                    'arbitrary_value',
+                    int,
+                    'Some settable value',
+                    settable_object=self._arbitrary,
+                    settable_attrib_name='some_value',
+                )
+            )
+
+    # Declare a CommandSet with an empty settable prefix
+    class WithSettablesNoPrefix(CommandSetBase):
+        def __init__(self):
+            super(WithSettablesNoPrefix, self).__init__()
+
+            self._arbitrary = Arbitrary()
+            self._settable_prefix = ''
+            self.my_int = 11
+
+            self.add_settable(
+                Settable(
+                    'another_value',
+                    float,
+                    'Some settable value',
+                    settable_object=self._arbitrary,
+                    settable_attrib_name='some_value',
+                )
+            )
+
+    # Declare a commandset with duplicate settable name
+    class WithSettablesB(CommandSetBase):
+        def __init__(self):
+            super(WithSettablesB, self).__init__()
+
+            self._arbitrary = Arbitrary()
+            self._settable_prefix = 'some'
+            self.my_int = 11
+
+            self.add_settable(
+                Settable(
+                    'arbitrary_value',
+                    int,
+                    'Some settable value',
+                    settable_object=self._arbitrary,
+                    settable_attrib_name='some_value',
+                )
+            )
+
+    # create the command set and cmd2
+    cmdset = WithSettablesA()
+    arbitrary2 = Arbitrary()
+    app = cmd2.Cmd(command_sets=[cmdset], auto_load_commands=False)
+    setattr(app, 'str_value', '')
+    app.add_settable(Settable('always_prefix_settables', bool, 'Prefix settables', app))
+    app._settables['str_value'] = Settable('str_value', str, 'String value', app)
+
+    assert 'arbitrary_value' in app.settables.keys()
+    assert 'always_prefix_settables' in app.settables.keys()
+    assert 'str_value' in app.settables.keys()
+
+    # verify the settable shows up
+    out, err = run_cmd(app, 'set')
+    assert 'arbitrary_value: 5' in out
+    out, err = run_cmd(app, 'set arbitrary_value')
+    assert out == ['arbitrary_value: 5']
+
+    # change the value and verify the value changed
+    out, err = run_cmd(app, 'set arbitrary_value 10')
+    expected = """
+arbitrary_value - was: 5
+now: 10
+"""
+    assert out == normalize(expected)
+    out, err = run_cmd(app, 'set arbitrary_value')
+    assert out == ['arbitrary_value: 10']
+
+    # can't add to cmd2 now because commandset already has this settable
+    with pytest.raises(KeyError):
+        app.add_settable(Settable('arbitrary_value', int, 'This should fail', app))
+
+    cmdset.add_settable(
+        Settable('arbitrary_value', int, 'Replaced settable', settable_object=arbitrary2, settable_attrib_name='some_value')
+    )
+
+    # Can't add a settable to the commandset that already exists in cmd2
+    with pytest.raises(KeyError):
+        cmdset.add_settable(Settable('always_prefix_settables', int, 'This should also fail', cmdset))
+
+    # Can't remove a settable from the CommandSet if it is elsewhere and not in the CommandSet
+    with pytest.raises(KeyError):
+        cmdset.remove_settable('always_prefix_settables')
+
+    # verify registering a commandset with duplicate settable names fails
+    cmdset_dupname = WithSettablesB()
+    with pytest.raises(CommandSetRegistrationError):
+        app.register_command_set(cmdset_dupname)
+
+    # unregister the CommandSet and verify the settable is now gone
+    app.unregister_command_set(cmdset)
+    out, err = run_cmd(app, 'set')
+    assert 'arbitrary_value' not in out
+    out, err = run_cmd(app, 'set arbitrary_value')
+    expected = """
+Parameter 'arbitrary_value' not supported (type 'set' for list of parameters).
+"""
+    assert err == normalize(expected)
+
+    # Add a commandset with no prefix
+    cmdset_nopfx = WithSettablesNoPrefix()
+    app.register_command_set(cmdset_nopfx)
+
+    with pytest.raises(ValueError):
+        app.always_prefix_settables = True
+
+    app.unregister_command_set(cmdset_nopfx)
+
+    # turn on prefixes and add the commandset back
+    app.always_prefix_settables = True
+
+    with pytest.raises(CommandSetRegistrationError):
+        app.register_command_set(cmdset_nopfx)
+
+    app.register_command_set(cmdset)
+
+    # Verify the settable is back with the defined prefix.
+    assert 'addon.arbitrary_value' in app.settables.keys()
+
+    # rename the prefix and verify that the prefix changes everywhere
+    cmdset._settable_prefix = 'some'
+    assert 'addon.arbitrary_value' not in app.settables.keys()
+    assert 'some.arbitrary_value' in app.settables.keys()
+
+    out, err = run_cmd(app, 'set')
+    assert 'some.arbitrary_value: 5' in out
+    out, err = run_cmd(app, 'set some.arbitrary_value')
+    assert out == ['some.arbitrary_value: 5']
+
+    # verify registering a commandset with duplicate prefix and settable names fails
+    with pytest.raises(CommandSetRegistrationError):
+        app.register_command_set(cmdset_dupname)
+
+    cmdset_dupname.remove_settable('arbitrary_value')
+
+    app.register_command_set(cmdset_dupname)
+
+    with pytest.raises(KeyError):
+        cmdset_dupname.add_settable(
+            Settable(
+                'arbitrary_value',
+                int,
+                'Some settable value',
+                settable_object=cmdset_dupname._arbitrary,
+                settable_attrib_name='some_value',
+            )
+        )
